//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Pon](index.md)/[tiles](tiles.md)

# tiles

[common]\
open override val [tiles](tiles.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../-tile/index.md)&gt;
